1.0.0 API documentation: raw_data.hpp Source File

| 1.0.0 API documentation

raw_data.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependencies
16 #include "../ext/scalar_uint_sized.hpp"
17 #include "../detail/setup.hpp"
18
19 #ifndef GLM_ENABLE_EXPERIMENTAL
20 # error "GLM: GLM_GTX_raw_data is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
21 #elif GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
22 # pragma message("GLM: GLM_GTX_raw_data extension included")
23 #endif
24
25 namespace glm
26 {
29
32 typedef detail::uint8 byte;
33
36 typedef detail::uint16 word;
37
40 typedef detail::uint32 dword;
41
44 typedef detail::uint64 qword;
45
47 }// namespace glm
48
49 #include "raw_data.inl"
glm::word
detail::uint16 word
Type for word numbers.
Definition: raw_data.hpp:36
glm::dword
detail::uint32 dword
Type for dword numbers.
Definition: raw_data.hpp:40
glm::byte
detail::uint8 byte
Type for byte numbers.
Definition: raw_data.hpp:32
glm::qword
detail::uint64 qword
Type for qword numbers.
Definition: raw_data.hpp:44